@@ -1,22 +1,35 @@
-from typing import List
+from typing import Dict, List
 
 from airflow.models.baseoperator import BaseOperator
 
 
 class ModelExecutionTask:
-    def __init__(self, run_airflow_task: BaseOperator, test_airflow_task: BaseOperator):
+    def __init__(
+        self,
+        run_airflow_task: BaseOperator,
+        test_airflow_task: BaseOperator,
+        task_group=None,
+    ):
         self.run_airflow_task = run_airflow_task
         self.test_airflow_task = test_airflow_task
+        self.task_group = task_group
 
-    # todo only for airflow 2.x
-    def to_task_group(self):
-        return None
+    def __repr__(self):
+        return repr(self.task_group) or repr(
+            [self.run_airflow_task, self.test_airflow_task]
+        )
+
+    def get_start_task(self):
+        return self.task_group or self.run_airflow_task
+
+    def get_end_task(self):
+        return self.task_group or self.test_airflow_task
 
 
 class ModelExecutionTasks:
     def __init__(
         self,
-        tasks: List[ModelExecutionTask],
+        tasks: Dict[str, ModelExecutionTask],
         starting_task_names: List[str],
         ending_task_names: List[str],
     ):
@@ -24,6 +37,9 @@ class ModelExecutionTasks:
         self._starting_task_names = starting_task_names
         self._ending_task_names = ending_task_names
 
+    def __repr__(self):
+        return f"ModelExecutionTasks(\n {self._tasks} \n)"
+
     def get_task(self, node_name) -> ModelExecutionTask:
         return self._tasks[node_name]
 
